GetAddresses class abstract

Constructors

GetAddresses()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAppNotActive(String appName) → void
onEmpty() → void
onError(dynamic error) → void
onLoadfinished() → void
onLoading() → void
onNotLoggedIn() → void
onResult(String appName, int itemCount, List<Map<String, dynamic>> addresses) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited