GetAppInfo class abstract

Constructors

GetAppInfo()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAppNotActive(String appName) → void
onError(dynamic error) → void
onHomeCover(String homeCover) → void
onLoadfinished() → void
onLoading() → void
onResult(String appName, String appIcon, int appType, Map<String, dynamic> appLocation) → void
onWhatsappChat(int dialingCode, int phoneNumber) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited