Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onAnnouncement(String announcementBody)
→ void
-
-
onAppLocation(String appLocation, double latitude, double longitude)
→ void
-
-
onAppNotActive(String appName)
→ void
-
-
onEmpty(String appName, String appIcon, String categoryName, String categoryIcon)
→ void
-
-
onError(dynamic error)
→ void
-
-
onHomeCover(String cover)
→ void
-
-
onLoadfinished()
→ void
-
-
onLoading()
→ void
-
-
onNextPage(int nextPage)
→ void
-
-
onNoNextPage()
→ void
-
-
onNotFound()
→ void
-
-
onResult(String categoryId, String appName, String appIcon, String categoryName, String categoryIcon, int totalItemCount, int itemsInThisPage, int itemsPerPage, List items)
→ void
-
-
onUnderConstruction()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited