GetItemsSearchLoadMore class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppNotActive(
String appName) → void -
onEmpty(
) → void -
onError(
dynamic error) → void -
onLoadfinished(
) → void -
onLoading(
) → void -
onNextPage(
int nextPage) → void -
onNoNextPage(
) → void -
onNotFound(
) → void -
onResult(
int totalItemCount, int itemsInThisPage, int itemsPerPage, List items) → void -
onUnderConstruction(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited