GetPage class abstract

Constructors

GetPage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAnnouncement(String announcementBody) → void
onAppLocation(String appLocation, double latitude, double longitude) → void
onAppNotActive(String appName) → void
onError(dynamic error) → void
onHomeCover(String cover) → void
onLoadfinished() → void
onLoading() → void
onNotFound() → void
onResult(String appName, String appIcon, String pageTitle, String pageBody) → void
onUnderConstruction() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited