Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onAddressNotAvailable()
→ void
-
-
onAppNotActive(String appName)
→ void
-
-
onEmpty()
→ void
-
-
onError(dynamic error)
→ void
-
-
onLoadfinished()
→ void
-
-
onLoading()
→ void
-
-
onNotLoggedIn()
→ void
-
-
onPhonePe(String paymentLink)
→ void
-
-
onPinCodeNotServicable()
→ void
-
-
onRazorpay(String key)
→ void
-
-
onResult(String appName, String appIcon, String currency, int totalItems, String currencySymbol, double totalAmount, String orderId, String customerName, String customerAddress, String customerCity, String customerState, String customerPostalCode, String customerPhoneNumber, int paymentType, List items)
→ void
-
-
onStripe(String clientSecret, String publishableKey)
→ void
-
-
onTimeSlots(List dates, List slots)
→ void
-
-
onVariantNotFound()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited