GetVariant class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onAppNotActive(
String appName) → void -
onBadRequest(
String status) → void -
onError(
dynamic error) → void -
onLoadfinished(
) → void -
onLoading(
) → void -
onNotFound(
) → void -
onResult(
String variantTag, String variantId, Map< String, dynamic> variantExtras, String variantImage, Map<String, dynamic> variantImages) → void -
onUnderConstruction(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited